---
layout: default
---

<article class="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 py-12">
    <!-- Post Header -->
    <header class="mb-12">
        <h1 class="text-4xl font-bold text-gray-900 mb-4">{{ page.title }}</h1>
        
        <div class="flex items-center text-gray-600 mb-6">
            <time datetime="{{ page.date | date_to_xmlschema }}" class="mr-4">
                {{ page.date | date: "%B %d, %Y" }}
            </time>
            <span class="mr-4">•</span>
            <span>By {{ page.author | default: site.author }}</span>
        </div>
        
        {% if page.image %}
        <img src="{{ page.image | relative_url }}" 
             alt="{{ page.title }}" 
             class="w-full h-64 object-cover rounded-lg shadow-lg">
        {% endif %}
    </header>
    
    <!-- Post Content -->
    <div class="prose prose-lg max-w-none">
        {{ content }}
    </div>
    
    <!-- Post Footer -->
    <footer class="mt-12 pt-8 border-t border-gray-200">
        <div class="flex flex-col sm:flex-row justify-between items-start sm:items-center">
            <div class="mb-4 sm:mb-0">
                <h3 class="text-lg font-semibold text-gray-900 mb-2">About the Author</h3>
                <p class="text-gray-600">
                    {{ page.author_bio | default: page.author | default: site.author }}
                </p>
            </div>
            
            <div class="flex space-x-4">
                <a href="https://github.com/Oppkey/FastOpp" 
                   class="text-gray-600 hover:text-ai-blue transition-colors"
                   target="_blank" rel="noopener">
                    <svg class="h-6 w-6" fill="currentColor" viewBox="0 0 24 24">
                        <path d="M12 0c-6.626 0-12 5.373-12 12 0 5.302 3.438 9.8 8.207 11.387.599.111.793-.261.793-.577v-2.234c-3.338.726-4.033-1.416-4.033-1.416-.546-1.387-1.333-1.756-1.333-1.756-1.089-.745.083-.729.083-.729 1.205.084 1.839 1.237 1.839 1.237 1.07 1.834 2.807 1.304 3.492.997.107-.775.418-1.305.762-1.604-2.665-.305-5.467-1.334-5.467-5.931 0-1.311.469-2.381 1.236-3.221-.124-.303-.535-1.524.117-3.176 0 0 1.008-.322 3.301 1.23.957-.266 1.983-.399 3.003-.404 1.02.005 2.047.138 3.006.404 2.291-1.552 3.297-1.23 3.297-1.23.653 1.653.242 2.874.118 3.176.77.84 1.235 1.911 1.235 3.221 0 4.609-2.807 5.624-5.479 5.921.43.372.823 1.102.823 2.222v3.293c0 .319.192.694.801.576 4.765-1.589 8.199-6.086 8.199-11.386 0-6.627-5.373-12-12-12z"/>
                    </svg>
                </a>
            </div>
        </div>
    </footer>
</article>

<!-- Navigation -->
<nav class="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 pb-12">
    <div class="flex justify-between">
        {% if page.previous %}
        <a href="{{ page.previous.url | relative_url }}" 
           class="flex items-center text-ai-blue hover:text-blue-700 transition-colors">
            <svg class="w-4 h-4 mr-2" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M15 19l-7-7 7-7"></path>
            </svg>
            Previous: {{ page.previous.title }}
        </a>
        {% else %}
        <div></div>
        {% endif %}
        
        {% if page.next %}
        <a href="{{ page.next.url | relative_url }}" 
           class="flex items-center text-ai-blue hover:text-blue-700 transition-colors">
            Next: {{ page.next.title }}
            <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M9 5l7 7-7 7"></path>
            </svg>
        </a>
        {% endif %}
    </div>
</nav>
